@@ -118,14 +118,25 @@ class Dnac:
         return data
 
     def id_from_serial(self, serialNumber):
-        switches = self.getAllDevices()
-        for switch in switches['response']:
-            if switch['serialNumber'] == serialNumber:
-                switchId = switch['id']
-        try:
-            return switchId
-        except KeyError:
-            return None
+        devices = self.getAllDevices()
+        for device in devices.get('response'):
+            if serialNumber in device.get('serialNumber'):
+                deviceId = device.get('id')
+                return deviceId
+
+        return None
+
+    def name_from_id(self, id:str) -> str:
+        """
+        Return a the name of a device in string format
+        """
+        devices = self.getAllDevices().get('response')
+        for device in devices:
+            if id == device.get('id'):
+                hostname = device.get('hostname')
+                return hostname
+        return None
+
 
     def getTemplates(self):
         endpoint = "template-programmer/project"
